@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.14";
+our $VERSION = "0.15";
 use Moo;
 use JSON::Tiny qw[decode_json];
 use strictures 2;
@@ -34,7 +34,7 @@ sub _build_raw {
     my $s = shift;
     my $url;
     if ($s->has_url) {
-        $url = $_[0]->_get_url;
+        $url = $s->_get_url;
     }
     elsif ($s->has_id) {
         $url = Finance::Robinhood::endpoint('instruments') . $s->id . '/';
